
import seo.translation

from django.contrib import admin

from modeltranslation.admin import TranslationAdmin

from seo.models import PageMeta


class PageMetaAdmin(TranslationAdmin):
    list_display = ('url', 'title', 'robots', )
    list_editable = ('robots', )


admin.site.register(PageMeta, PageMetaAdmin)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-01-16 15:46
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


def generate_operations():
    
    operations = []
    
    for code, name in settings.LANGUAGES:
        
        operations += [
            
            migrations.AddField(
                model_name='pagemeta',
                name='breadcrumb_%s' % code,
                field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Breadcrumb'),
            ),
            migrations.AddField(
                model_name='pagemeta',
                name='description_%s' % code,
                field=models.CharField(blank=True, max_length=155, null=True, verbose_name='Description'),
            ),
            migrations.AddField(
                model_name='pagemeta',
                name='header_%s' % code,
                field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Header'),
            ),
            migrations.AddField(
                model_name='pagemeta',
                name='keywords_%s' % code,
                field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Keywords'),
            ),
            migrations.AddField(
                model_name='pagemeta',
                name='title_%s' % code,
                field=models.CharField(max_length=68, null=True, verbose_name='Title'),
            ),            
            
        ]

    return operations


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0001_initial'),
    ]

    operations = generate_operations()
